@@ -2,7 +2,7 @@
 /*
  * gsf-impl-utils.h: 
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -27,7 +27,10 @@
 
 G_BEGIN_DECLS
 
-/* We need to do this with a version check as this header gets installed.  */
+/* We need to do this with a version check as this header gets installed.
+ *
+ * DEPRECATED in favour of G_PARAM_STATIC_STRINGS
+ **/
 #if GLIB_CHECK_VERSION(2,7,0)
 #define GSF_PARAM_STATIC (G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB)
 #else
@@ -37,13 +40,13 @@ G_BEGIN_DECLS
 /*************************************************************************/
 
 #define	GSF_CLASS_FULL(name, prefix, base_init, base_finalize, \
-			   class_init, class_finalize, instance_init, parent_type, \
+		       class_init, class_finalize, instance_init, parent_type, \
 		       abstract, interface_decl) \
 GType									\
 prefix ## _get_type (void)						\
 {									\
 	static GType type = 0;						\
-	if (type == 0) {						\
+	if (G_UNLIKELY  (type == 0)) {					\
 		static GTypeInfo const object_info = {			\
 			sizeof (name ## Class),				\
 			(GBaseInitFunc) base_init,			\
@@ -63,6 +66,19 @@ prefix ## _get_type (void)						\
 	return type;							\
 }
 
+/**
+ * GSF_CLASS:
+ * @name: (string) Name of the class.
+ * @prefix: (string) Prefix designating the namespace to be used for
+ * implementing the class.
+ * @class_init: (#GClassInitFunc) Initialisation function for the class.
+ * @instance_init: (#GInstanceInitFunc) Initialisation (constructor) function
+ * for an instance of the class.
+ * @parent: Parent class to this class.
+ *
+ * Set up a GSF class.
+ *
+ */
 #define	GSF_CLASS(name, prefix, class_init, instance_init, parent) \
 	GSF_CLASS_FULL(name, prefix, NULL, NULL, class_init, NULL, \
 				instance_init, parent, 0, {})
@@ -98,7 +114,7 @@ prefix ## _get_type ()							\
 void									\
 prefix ## _register_type (GTypeModule *module)				\
 {									\
-	static GTypeInfo const type_info = {				\
+	GTypeInfo const type_info = {					\
 		sizeof (name ## Class),					\
 		(GBaseInitFunc) base_init,				\
 		(GBaseFinalizeFunc) base_finalize,			\
@@ -120,14 +136,14 @@ prefix ## _register_type (GTypeModule *module)				\
 }
 
 #define	GSF_DYNAMIC_CLASS(name, prefix, class_init, instance_init, parent)	\
-	GSF_DYNAMIC_CLASS_FULL(name, prefix, NULL, NULL, class_init, NULL, \
+	GSF_DYNAMIC_CLASS_FULL(name, prefix, NULL, NULL, class_init, NULL, 	\
 				   instance_init, parent, 0, {})
 #define	GSF_DYNAMIC_CLASS_ABSTRACT(name, prefix, class_init, instance_init, parent) \
-	GSF_DYNAMIC_CLASS_FULL(name, prefix, NULL, NULL, class_init, NULL, \
+	GSF_DYNAMIC_CLASS_FULL(name, prefix, NULL, NULL, class_init, NULL, 	\
 		       instance_init, parent, G_TYPE_FLAG_ABSTRACT, {})
 
 #define GSF_DYNAMIC_INTERFACE_FULL(type, init_func, iface_type, module) {	\
-	static GInterfaceInfo const iface = {					\
+	GInterfaceInfo const iface = {						\
 		(GInterfaceInitFunc) init_func, NULL, NULL };			\
 	g_type_module_add_interface (module, type, iface_type, &iface);		\
 }
