@@ -350,12 +350,12 @@ gsf_xml_parser_context (GsfInput *input)
 
 /**
  * gsf_xml_output_buffer_new :
- * @output:
+ * @output: #GsfOutput
  * @encoding: optionally %NULL.
  *
  * <note>This adds a reference to @output.</note>
  * <note>This is <emphasis>not</emphasis> releated to #GsfXMLOut.</note>
- */
+ **/
 static xmlOutputBufferPtr
 gsf_xml_output_buffer_new (GsfOutput *output,
 			   xmlCharEncodingHandlerPtr handler)
@@ -371,6 +371,17 @@ gsf_xml_output_buffer_new (GsfOutput *output,
 	return res;
 }
 
+/**
+ * gsf_xmlDocFormatDump :
+ * @output : #GsfOutput
+ * @cur : #xmlDocPtr
+ * @encoding : The encoding to use.
+ * @format : %TRUE to reformat the output.
+ *
+ * Dumps the document @cur into @output.
+ *
+ * Returns: status from xmlSaveFormatFileTo.
+ **/
 int
 gsf_xmlDocFormatDump (GsfOutput *output, xmlDocPtr cur, char const *encoding,
 		      gboolean format)
@@ -904,8 +915,6 @@ GsfXMLInDoc *
 gsf_xml_in_doc_new (GsfXMLInNode const *nodes, GsfXMLInNS const *ns)
 {
 	GsfXMLInDoc  *doc;
-	GsfXMLInNode const *e_node;
-	GsfXMLInNodeInternal *tmp, *node;
 
 	g_return_val_if_fail (nodes != NULL, NULL);
 
@@ -915,6 +924,33 @@ gsf_xml_in_doc_new (GsfXMLInNode const *nodes, GsfXMLInNS const *ns)
 		NULL, (GDestroyNotify) gsf_xml_in_node_internal_free);
 	doc->ns        = ns;
 
+	gsf_xml_in_doc_add_nodes (doc, nodes);
+
+	if (NULL == doc->root_node) {
+		gsf_xml_in_doc_free (doc);
+		g_return_val_if_fail (NULL != doc->root_node, NULL);
+	}
+
+	return doc;
+}
+
+/**
+ * gsf_xml_in_doc_add_nodes :
+ * @doc : #GsfXMLInDoc
+ * @nodes : %NULL terminated array of #GsfXMLInNode
+ *
+ * Adds additional nodes to the structure of @doc
+ **/
+void
+gsf_xml_in_doc_add_nodes (GsfXMLInDoc *doc,
+			  GsfXMLInNode const *nodes)
+{
+	GsfXMLInNode const *e_node;
+	GsfXMLInNodeInternal *tmp, *node;
+
+	g_return_if_fail (doc != NULL);
+	g_return_if_fail (nodes != NULL);
+
 	for (e_node = nodes; e_node->id != NULL ; e_node++ ) {
 		node = g_hash_table_lookup (doc->symbols, e_node->id);
 		if (node != NULL) {
@@ -941,7 +977,7 @@ gsf_xml_in_doc_new (GsfXMLInNode const *nodes, GsfXMLInNS const *ns)
 			g_hash_table_insert (doc->symbols,
 				(gpointer)node->pub.id, node);
 		}
-		if (e_node == nodes) /* first valid node is the root */
+		if (NULL == doc->root_node && e_node == nodes) /* first valid node is the root */
 			doc->root_node = node;
 
 		/* NOTE : use e_node for parent_id rather than node
@@ -967,8 +1003,6 @@ gsf_xml_in_doc_new (GsfXMLInNode const *nodes, GsfXMLInNS const *ns)
 			continue;
 		}
 	}
-
-	return doc;
 }
 
 /**
@@ -990,7 +1024,7 @@ gsf_xml_in_doc_set_unknown_handler (GsfXMLInDoc *doc,
  * gsf_xml_in_push_state :
  * @xin : #GsfXMLIn
  * @doc : #GsfXMLInDoc
- * @new_state :
+ * @new_state : arbitrary content for the parser
  * @dtor : #GsfXMLInExtDtor
  * @attrs : array of xmlChar const *
  *
@@ -1023,7 +1057,7 @@ gsf_xml_in_push_state (GsfXMLIn *xin, GsfXMLInDoc const *doc,
  * gsf_xml_in_doc_parse :
  * @doc : #GsfXMLInDoc
  * @input : #GsfInput
- * @user_state :
+ * @user_state : arbitrary content stored in the parser
  *
  * Read an xml document from @input and parse based on the the descriptor in
  * @doc
@@ -1073,13 +1107,13 @@ gsf_xml_in_get_input (GsfXMLIn const *xin)
 /**
  * gsf_xml_in_check_ns :
  * @xin : #GsfXMLIn
- * @str :
- * @ns_id :
+ * @str : string to check
+ * @ns_id : the namespace id
  * 
  * According to @state is @str in the namespace @ns_id ?
  *
  * Returns: a pointer to @str after the namespace if successful,
- * 	otherwise NULL.
+ * 	otherwise %NULL.
  **/
 char const *
 gsf_xml_in_check_ns (GsfXMLIn const *xin, char const *str, unsigned int ns_id)
@@ -1108,6 +1142,9 @@ gsf_xml_in_check_ns (GsfXMLIn const *xin, char const *str, unsigned int ns_id)
  * @ns_id : The name space id to check
  * @name  : The target node name
  *
+ * Checks to see if @str is the same as @ns_id::@name with either an explicit
+ * namespace or the current default namespace.
+ *
  * Returns: %TRUE if @str == @ns_id:@name according to @state.
  **/
 gboolean
@@ -1758,6 +1795,14 @@ gsf_xml_out_add_base64 (GsfXMLOut *xout, char const *id,
 	g_free (tmp);
 }
 
+/**
+ * gsf_xml_out_get_output :
+ * @xout : #GsfXMLOut
+ *
+ * Get the #GsfInput we are parsing from.
+ *
+ * Returns: #GsfInput or %NULL.
+ **/
 GsfOutput *
 gsf_xml_out_get_output (GsfXMLOut const *xout)
 {
