@@ -231,11 +231,11 @@ GSF_CLASS (GsfOutputBzip, gsf_output_bzip,
 /**
  * gsf_output_bzip_new :
  * @sink : The underlying data source.
- * @err	   : optionally NULL.
+ * @err	   : optionally %NULL.
  *
  * Adds a reference to @sink.
  *
- * Returns a new file or NULL.
+ * Returns: a new file or %NULL.
  **/
 GsfOutput *
 gsf_output_bzip_new (GsfOutput *sink, GError **err)
@@ -246,6 +246,8 @@ gsf_output_bzip_new (GsfOutput *sink, GError **err)
 	g_return_val_if_fail (GSF_IS_OUTPUT (sink), NULL);
 
 	bzip = g_object_new (GSF_OUTPUT_BZIP_TYPE, NULL);
+	if (G_UNLIKELY (NULL == bzip)) return NULL;
+
 	g_object_ref (G_OBJECT (sink));
 	bzip->sink = sink;
 
