@@ -146,15 +146,17 @@ gsf_output_memory_vprintf (GsfOutput *output, char const *format, va_list args)
 		 */
 		G_VA_COPY (args2, args);
 
-		len =
-			g_vsnprintf (mem->buffer + output->cur_offset,
-				     mem->capacity - output->cur_offset,
-				     format, args);
+		len = g_vsnprintf (mem->buffer + output->cur_offset,
+				   mem->capacity - output->cur_offset,
+				   format, args);
 
-		if (len < (gsf_off_t)(mem->capacity - output->cur_offset))
-			return len; /* There was sufficient space */
+		/* There was insufficient space */
+		if (len >= (gsf_off_t)(mem->capacity - output->cur_offset))
+			len = parent_class->Vprintf (output, format, args2);
 
-		return parent_class->Vprintf (output, format, args2);
+		va_end (args2);
+
+		return len;
 	}
 	return parent_class->Vprintf (output, format, args);
 }
